@@ -10,6 +10,7 @@ use vrp_cli::extensions::solve::config::create_builder_from_config_file;
 use vrp_cli::{get_errors_serialized, get_locations_serialized};
 use vrp_core::models::{Problem, Solution};
 use vrp_core::solver::{Builder, Metrics, Telemetry, TelemetryMode};
+use vrp_core::utils::{DefaultRandom, Random};
 
 const FORMAT_ARG_NAME: &str = "FORMAT";
 const PROBLEM_ARG_NAME: &str = "PROBLEM";
@@ -25,7 +26,6 @@ const GET_LOCATIONS_ARG_NAME: &str = "get-locations";
 const CONFIG_ARG_NAME: &str = "config";
 const LOG_ARG_NAME: &str = "log";
 const CHECK_ARG_NAME: &str = "check";
-const RANDOM_SEED_NAME: &str = "seed";
 
 #[allow(clippy::type_complexity)]
 struct ProblemReader(pub Box<dyn Fn(File, Option<Vec<File>>) -> Result<Problem, String>>);
@@ -51,7 +51,7 @@ struct LocationWriter(pub Box<dyn Fn(File, BufWriter<Box<dyn Write>>) -> Result<
 #[allow(clippy::type_complexity)]
 type FormatMap<'a> = HashMap<&'a str, (ProblemReader, InitSolutionReader, SolutionWriter, LocationWriter)>;
 
-fn add_scientific(formats: &mut FormatMap) {
+fn add_scientific(formats: &mut FormatMap, random: Arc<dyn Random + Send + Sync>) {
     if cfg!(feature = "scientific-format") {
         use vrp_scientific::lilim::{LilimProblem, LilimSolution};
         use vrp_scientific::solomon::read_init_solution as read_init_solomon;
@@ -64,7 +64,9 @@ fn add_scientific(formats: &mut FormatMap) {
                     assert!(matrices.is_none());
                     BufReader::new(problem).read_solomon()
                 })),
-                InitSolutionReader(Box::new(|file, problem| read_init_solomon(BufReader::new(file), problem))),
+                InitSolutionReader(Box::new(move |file, problem| {
+                    read_init_solomon(BufReader::new(file), problem, random.clone())
+                })),
                 SolutionWriter(Box::new(|_, solution, _, writer, _| solution.write_solomon(writer))),
                 LocationWriter(Box::new(|_, _| unimplemented!())),
             ),
@@ -84,7 +86,7 @@ fn add_scientific(formats: &mut FormatMap) {
     }
 }
 
-fn add_pragmatic(formats: &mut FormatMap) {
+fn add_pragmatic(formats: &mut FormatMap, random: Arc<dyn Random + Send + Sync>) {
     use vrp_pragmatic::format::problem::{deserialize_problem, PragmaticProblem};
     use vrp_pragmatic::format::solution::read_init_solution as read_init_pragmatic;
     use vrp_pragmatic::format::solution::PragmaticSolution;
@@ -101,7 +103,9 @@ fn add_pragmatic(formats: &mut FormatMap) {
                 }
                 .map_err(|errors| errors.iter().map(|err| err.to_string()).collect::<Vec<_>>().join("\t\n"))
             })),
-            InitSolutionReader(Box::new(|file, problem| read_init_pragmatic(BufReader::new(file), problem))),
+            InitSolutionReader(Box::new(move |file, problem| {
+                read_init_pragmatic(BufReader::new(file), problem, random.clone())
+            })),
             SolutionWriter(Box::new(|problem, solution, metrics, default_writer, geojson_writer| {
                 geojson_writer
                     .map_or(Ok(()), |geojson_writer| solution.write_geo_json(problem, geojson_writer))
@@ -126,9 +130,11 @@ fn add_pragmatic(formats: &mut FormatMap) {
 
 fn get_formats<'a>() -> FormatMap<'a> {
     let mut formats = FormatMap::default();
+    // TODO pass random from outside
+    let random = Arc::new(DefaultRandom::default());
 
-    add_scientific(&mut formats);
-    add_pragmatic(&mut formats);
+    add_scientific(&mut formats, random.clone());
+    add_pragmatic(&mut formats, random);
 
     formats
 }
@@ -230,13 +236,6 @@ pub fn get_solve_app<'a, 'b>() -> App<'a, 'b> {
                 .required(false)
                 .takes_value(false),
         )
-        .arg(
-            Arg::with_name(RANDOM_SEED_NAME)
-                .help("Specifies randomization seed to avoid stochastic behavior")
-                .long(RANDOM_SEED_NAME)
-                .required(false)
-                .takes_value(true),
-        )
 }
 
 /// Runs solver commands.
@@ -274,7 +273,6 @@ pub fn run_solve(matches: &ArgMatches) {
     let out_result = matches.value_of(OUT_RESULT_ARG_NAME).map(|path| create_file(path, "out solution"));
     let out_geojson = matches.value_of(GEO_JSON_ARG_NAME).map(|path| create_file(path, "out geojson"));
     let is_get_locations_set = matches.is_present(GET_LOCATIONS_ARG_NAME);
-    let seed = parse_int_value::<u64>(matches, RANDOM_SEED_NAME, "seed");
 
     match formats.get(problem_format) {
         Some((problem_reader, init_reader, solution_writer, locations_writer)) => {
@@ -313,7 +311,6 @@ pub fn run_solve(matches: &ArgMatches) {
                                 .with_max_time(max_time)
                                 .with_cost_variation(cost_variation)
                                 .with_telemetry(telemetry)
-                                .with_seed(seed)
                         };
 
                         let (solution, _, metrics) = builder
